/**
 * 存储localStorage
 * @param {string}key
 * @param {any}value
 * @returns
 */
const SetLocalStorage = (key: string, value: any) => {
  if (!key) return;
  if (typeof value !== "string") {
    value = JSON.stringify(value);
  }
  window.localStorage.setItem(key, value);
};


/**
 * 获取localStorage
 * @param {string}key
 * @returns
 */
const GetLocalStorage = (key: string) => {
  if (!key) return;
  let data = window.localStorage.getItem(key);

  return data ? JSON.parse(data) : undefined;
};


/**
 * 删除localStorage
 * @param {string}key
 * @returns
 */
const RemoveLocalStorage = (key: string) => {
  if (!key) return;
  window.localStorage.removeItem(key);
};

/**
 * 删除所有localStorage
 * @param {string}key
 * @returns
 */
const RemoveLocalStorageAll = () => {
  window.localStorage.clear();
};

export {
  SetLocalStorage,
  GetLocalStorage,
  RemoveLocalStorage,
  RemoveLocalStorageAll
}
