/**
 * 对象转换url参数 遇到属性值为空或0就不拼接
 * @param obj
 * @returns
 */
function ObjToUrlParam(obj: Object) {
  let urlParam = '';
  Object.keys(obj).forEach(function (e) {
    if (obj[e]) {
      urlParam += `${e}=${obj[e]}&`
    }
  })
  if (urlParam.length > 0) {
    urlParam = urlParam.substring(0, urlParam.length - 1);
  }
  return urlParam;
}

/**
 * 给url添加参数 通过对象
 * @param url
 * @param obj
 * @returns
 */
function AddUrlParamFromObj(url: string, obj: Object) {
  if (url.indexOf("?") > -1) {
    url += "&" + ObjToUrlParam(obj);
  } else {
    if (obj && Object.keys(obj).length > 0) {
      url += "?" + ObjToUrlParam(obj);
    }
  }
  return url;
}

/**
 * 解析地址参数
 * @param url
 * @returns
 */
function AnalyzingUrl(url: string): { [key: string]: string } {
  if (url.indexOf("?") === -1) return {};
  const params: { [key: string]: string } = {};
  const obj = url.split('?')[1];
  const splits = obj.split("&");
  for (let i = 0, item; item = splits[i++];) {
    const splits_ = item.split("=");
    params[splits_[0]] = splits_[1];
  }
  return params;
}

/**
 * 编码
 * @param url
 */
function EncodeURIComponent(url: string) {
  return encodeURIComponent(url);
}

/**
 * 解码
 * @param url
 */
function DecodeURIComponent(url: string) {
  return decodeURIComponent(url);
}

export {
  ObjToUrlParam,
  AddUrlParamFromObj,
  AnalyzingUrl,
  EncodeURIComponent,
  DecodeURIComponent
}